@@ -7,8 +7,8 @@ kbandwidth.integer <-
   function(bw, ...) { kbandwidth.numeric(bw = bw, ...) }
 
 kbandwidth.default <- function(bw, ...){
-  kbandwidth.numeric(bw = bw$bw,
-                     bwscaling = bw$scaling,
+  kbandwidth.numeric(bw = unlist(bw$bandwidth),
+                     bwscaling = FALSE,
                      bwtype = bw$type,
                      ckertype = bw$ckertype,
                      ckerorder = bw$ckerorder,
@@ -26,10 +26,10 @@ kbandwidth.numeric <-
   function(bw,
            bwscaling = FALSE,
            bwtype = c("fixed","generalized_nn","adaptive_nn"),
-           ckertype = c("gaussian", "epanechnikov","uniform"), 
+           ckertype = c("gaussian","truncated gaussian","epanechnikov","uniform"),
            ckerorder = c(2,4,6,8),
            ukertype = c("aitchisonaitken", "liracine"),
-           okertype = c("wangvanryzin", "liracine"),
+           okertype = c("liracine","wangvanryzin", "nliracine"),
            nobs = NA,
            xdati = NULL,
            ydati = NULL,
@@ -51,6 +51,9 @@ kbandwidth.numeric <-
         stop("ckerorder must be one of ", paste(kord,collapse=" "))
     }
 
+    if(bwscaling != FALSE)
+        stop("npksum only uses raw bandwidths, therefore bwscaling = TRUE is not allowed")
+    
     ukertype = match.arg(ukertype)
     okertype = match.arg(okertype)
 
@@ -61,24 +64,14 @@ kbandwidth.numeric <-
       scaling = bwscaling,
       pscaling = ifelse(bwscaling, "Scale Factor(s)", "Bandwidth(s)"),
       type = bwtype,
-      ptype = switch( bwtype,
-        fixed = "Fixed",
-        generalized_nn = "Generalized Nearest Neighbour",
-        adaptive_nn = "Adaptive Nearest Neighbour" ),
+      ptype = bwtToPrint(bwtype),
       ckertype = ckertype,    
       ckerorder = ckerorder,
-      pckertype = switch(ckertype,
-        gaussian = paste(porder,"Gaussian"),
-        epanechnikov =  paste(porder,"Epanechnikov"),
-        uniform = "Uniform"),
+      pckertype = cktToPrint(ckertype, order = porder),
       ukertype = ukertype,
-      pukertype = switch( ukertype,
-        aitchisonaitken = "Aitchison and Aitken",
-        liracine = "Li and Racine"),
+      pukertype = uktToPrint(ukertype),
       okertype = okertype,
-      pokertype = switch( okertype,
-        wangvanryzin = "Wang and Van Ryzin",
-        liracine = "Li and Racine"),
+      pokertype = oktToPrint(okertype),
       nobs = nobs,
       ndim = ndim,
       ncon = sum(xdati$icon),
